@@ -7,7 +7,7 @@ use Math::String;
 @ISA = qw(Exporter Math::String);
 
 use vars qw($VERSION $accuracy $precision $fallback $rnd_mode);
-$VERSION = 0.04;
+$VERSION = 0.05;
 require  5.005;
 use strict;
 
@@ -31,7 +31,7 @@ my $bollocks;
 
 BEGIN
   {
-  $CALC = Math::BigInt::_core_lib();
+  $CALC = Math::BigInt->config()->{lib};
 
   # if we did this for every new() instead of in BEGIN, we would waste even
   # more resources. But we can't wait for management all day...
@@ -200,6 +200,7 @@ BEGIN
 	edge-of-your-seat
 	end-to-end
 	enterprise
+	enterprise-class
 	eligible
 	exceptional
 	extensible
@@ -281,14 +282,16 @@ BEGIN
 	customers
 	data
 	deliverables
+	developments
 	e-business
 	e-commerce
-	development
 	e-markets
 	e-services
 	e-tailers
+	environments
 	experiences
 	eyeballs
+	features
 	functionalities
 	infomediaries
 	information
@@ -621,6 +624,13 @@ up.
 
 =item *
 
+L<http://www.utsglobal.com/products.html>:
+
+...provide enterprise-class UNIX operating environments...
+...matched the unique scaleable, mission-critical features...
+
+=item *
+
 The journal I<Displays Europe, issue #1> provided lot's of, uh, well, genuine
 [mental note to self: add genuine to the list of adjectives] material:
 
